"""
:mod:`hepi` interface to Resummino.

Find it here https://resummino.hepforge.org/.
"""
from .run import run, set_path, get_path, default_resummino_runner,get_version
